@@ -470,7 +470,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP '%s'"],
+                    where = ["ur REGEXP %s"],
                     params = ['|'.join(patterns)])
         nd = len(neighs)
         fwnd = sum([ x.getFreq() for x in neighs])
@@ -517,7 +517,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP '%s'"],
+                    where = ["ur REGEXP %s"],
                     params = [pattern])
             totCount = WordType.objects.filter(Label__regex="^[^{<]").extra(
                     select = {
@@ -528,7 +528,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP '%s'"],
+                    where = ["ur REGEXP %s"],
                     params = [totPattern])
             SPprob += float(count) / float(totCount)
             if i != len(phones)-1:
@@ -545,7 +545,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP '%s'"],
+                    where = ["ur REGEXP %s"],
                     params = [pattern])
                 totCount = WordType.objects.filter(Label__regex="^[^{<]").extra(
                     select = {
@@ -556,7 +556,7 @@ class WordType(caching.base.CachingMixin,models.Model):
                                     = buckeyebrowser_underlying.SegmentType_id
                                 WHERE buckeyebrowser_underlying.WordType_id
                                     =buckeyebrowser_wordtype.id)"""},
-                    where = ["ur REGEXP '%s'"],
+                    where = ["ur REGEXP %s"],
                     params = [totPattern])
                 BPprob += float(count) / float(totCount)
         SPprob = SPprob / float(len(phones))
